.. _api_config:

.. py:module:: pynetdicom._config

Configuration Options (:mod:`pynetdicom._config`)
=================================================

.. currentmodule:: pynetdicom._config

.. autosummary::
   :toctree: generated/

   CODECS
   ENFORCE_UID_CONFORMANCE
   LOG_HANDLER_LEVEL
   LOG_REQUEST_IDENTIFIERS
   LOG_RESPONSE_IDENTIFIERS
   PASS_CONTEXTVARS
   STORE_RECV_CHUNKED_DATASET
   STORE_SEND_CHUNKED_DATASET
   USE_SHORT_DIMSE_AET
   UNRESTRICTED_STORAGE_SERVICE
   VALIDATORS
   WINDOWS_TIMER_RESOLUTION
